pub struct Codec {
builder: Builder,
state: DecodeState,
}Expand description
A codec which produces Bitcoin messages from byte streams and vice versa.
Fields
builder: Builderstate: DecodeStateImplementations
Sourceimpl Codec
impl Codec
Sourcefn body_length(&self, msg: &Message) -> usize
fn body_length(&self, msg: &Message) -> usize
Obtain the size of the body of a given message. This will match the
number of bytes written to the writer provided to write_body for the
same message.
Sourceimpl Codec
impl Codec
Sourcefn read_version<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_version<R: Read>(&self, reader: R) -> Result<Message, Error>
Deserializes a version message.
The relay field is optional, as defined in https://developer.bitcoin.org/reference/p2p_networking.html#version
Note: zcashd only requires fields up to address_recv, but everything up to relay is required in Zebra.
see https://github.com/zcash/zcash/blob/11d563904933e889a11d9685c3b249f1536cfbe7/src/main.cpp#L6490-L6507
fn read_verack<R: Read>(&self, _reader: R) -> Result<Message, Error>
fn read_ping<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_pong<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_reject<R: Read>(&self, reader: R) -> Result<Message, Error>
Sourcepub(super) fn read_addr<R: Read>(&self, reader: R) -> Result<Message, Error>
pub(super) fn read_addr<R: Read>(&self, reader: R) -> Result<Message, Error>
Deserialize an addr (v1) message into a list of MetaAddrs.
Sourcepub(super) fn read_addrv2<R: Read>(&self, reader: R) -> Result<Message, Error>
pub(super) fn read_addrv2<R: Read>(&self, reader: R) -> Result<Message, Error>
Deserialize an addrv2 message into a list of MetaAddrs.
Currently, Zebra parses received addrv2s, ignoring some address types.
Zebra never sends addrv2 messages.
fn read_getaddr<R: Read>(&self, _reader: R) -> Result<Message, Error>
fn read_block<R: Read + Send>(&self, reader: R) -> Result<Message, Error>
fn read_getblocks<R: Read>(&self, reader: R) -> Result<Message, Error>
Sourcefn read_headers<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_headers<R: Read>(&self, reader: R) -> Result<Message, Error>
Deserialize a headers message.
See [Zcash block header] for the enumeration of these fields.
fn read_getheaders<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_inv<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_getdata<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_notfound<R: Read>(&self, reader: R) -> Result<Message, Error>
fn read_tx<R: Read + Send>(&self, reader: R) -> Result<Message, Error>
fn read_mempool<R: Read>(&self, _reader: R) -> Result<Message, Error>
fn read_filterload<R: Read>( &self, reader: R, body_len: usize, ) -> Result<Message, Error>
fn read_filteradd<R: Read>( &self, reader: R, body_len: usize, ) -> Result<Message, Error>
fn read_filterclear<R: Read>(&self, _reader: R) -> Result<Message, Error>
Sourcefn deserialize_transaction_spawning<R: Read + Send>(
reader: R,
) -> Result<Transaction, Error>
fn deserialize_transaction_spawning<R: Read + Send>( reader: R, ) -> Result<Transaction, Error>
Given the reader, deserialize the transaction in the rayon thread pool.